@@ -1,5 +1,7 @@
 # frozen_string_literal: true
-$:.unshift File.expand_path("../../lib", __FILE__)
+
+lib = File.expand_path("../../lib", __FILE__)
+$LOAD_PATH.unshift(lib) unless $LOAD_PATH.include?(lib)
 
 begin
   if ENV["COVERALLS"]
