@@ -1,7 +1,6 @@
 # frozen_string_literal: true
 require File.expand_path("../helper", __FILE__)
 require "fileutils"
-require "stringio"
 
 class TestRakeFileUtils < Rake::TestCase # :nodoc:
   def setup
@@ -56,7 +55,7 @@ class TestRakeFileUtils < Rake::TestCase # :nodoc:
   end
 
   def test_ln
-    open("a", "w") { |f| f.puts "TEST_LN" }
+    File.write("a", "TEST_LN\n")
 
     Rake::FileUtilsExt.safe_ln("a", "b", verbose: false)
 
@@ -410,48 +409,46 @@ class TestRakeFileUtils < Rake::TestCase # :nodoc:
   end
 
   def command(name, text)
-    open name, "w", 0750 do |io|
-      io << text
-    end
+    File.write(name, text)
   end
 
   def check_no_expansion
-    command "check_no_expansion.rb", <<-CHECK_EXPANSION
-if ARGV[0] != ARGV[1]
-  exit 0
-else
-  exit 1
-end
+    command "check_no_expansion.rb", <<~CHECK_EXPANSION
+      if ARGV[0] != ARGV[1]
+        exit 0
+      else
+        exit 1
+      end
     CHECK_EXPANSION
   end
 
   def check_environment
-    command "check_environment.rb", <<-CHECK_ENVIRONMENT
-if ENV[ARGV[0]] != ARGV[1]
-  exit 1
-else
-  exit 0
-end
+    command "check_environment.rb", <<~CHECK_ENVIRONMENT
+      if ENV[ARGV[0]] != ARGV[1]
+        exit 1
+      else
+        exit 0
+      end
     CHECK_ENVIRONMENT
   end
 
   def check_expansion
-    command "check_expansion.rb", <<-CHECK_EXPANSION
-if ARGV[0] != ARGV[1]
-  exit 1
-else
-  exit 0
-end
+    command "check_expansion.rb", <<~CHECK_EXPANSION
+      if ARGV[0] != ARGV[1]
+        exit 1
+      else
+        exit 0
+      end
     CHECK_EXPANSION
   end
 
   def echocommand
-    command "echocommand.rb", <<-ECHOCOMMAND
-#!/usr/bin/env ruby
+    command "echocommand.rb", <<~ECHOCOMMAND
+      #!/usr/bin/env ruby
 
-puts "echocommand.rb"
+      puts "echocommand.rb"
 
-exit 0
+      exit 0
     ECHOCOMMAND
   end
 
@@ -466,10 +463,10 @@ exit 0
   end
 
   def shellcommand
-    command "shellcommand.rb", <<-SHELLCOMMAND
-#!/usr/bin/env ruby
+    command "shellcommand.rb", <<~SHELLCOMMAND
+      #!/usr/bin/env ruby
 
-exit((ARGV[0] || "0").to_i)
+      exit((ARGV[0] || "0").to_i)
     SHELLCOMMAND
   end
 
