@@ -1,7 +1,5 @@
 # frozen_string_literal: true
 require File.expand_path("../helper", __FILE__)
-require "fileutils"
-require "open3"
 
 class TestRakeFunctional < Rake::TestCase # :nodoc:
   include RubyRunner
