@@ -53,11 +53,8 @@ class TestRakeRakeTestLoader < Rake::TestCase # :nodoc:
       exc = assert_raises(LoadError) do
         load @loader
       end
-      if RUBY_ENGINE == "jruby"
-        assert_equal "no such file to load -- superkalifragilisticoespialidoso", exc.message
-      else
-        assert_equal "cannot load such file -- superkalifragilisticoespialidoso", exc.message
-      end
+
+      assert_match /.* -- superkalifragilisticoespialidoso/, exc.message
     end
     assert_empty out
     assert_empty err
